@@ -11,6 +11,7 @@
 #include <DGuiApplicationHelper>
 
 #include "dthememanager.h"
+#include "../3rdparty/core/settings.h"
 
 const int KEYPADHEIGHT = 350; //整体键盘的高度
 const QSize BUTTON_SIZE = QSize(69, 46); //科学模式的固定大小
@@ -109,6 +110,7 @@ ScientificKeyPad::ScientificKeyPad(QWidget *parent)
     , m_logyxwidget(new QStackedWidget(this))
     , m_exwidget(new QStackedWidget(this))
 {
+    qDebug() << "ScientificKeyPad constructor called";
     this->setFixedHeight(KEYPADHEIGHT);
     m_leftBracket->setFixedSize(24, 14);
     m_rightBracket->setFixedSize(24, 14);
@@ -128,6 +130,7 @@ ScientificKeyPad::ScientificKeyPad(QWidget *parent)
 
 ScientificKeyPad::~ScientificKeyPad()
 {
+    qDebug() << "ScientificKeyPad destructor called";
 }
 
 void ScientificKeyPad::mouseMoveEvent(QMouseEvent *e)
@@ -197,6 +200,7 @@ bool ScientificKeyPad::buttonHasFocus()
  */
 void ScientificKeyPad::initButtons()
 {
+    qDebug() << "Initializing scientific keypad buttons";
     const int count = sizeof(keyDescriptions) / sizeof(keyDescriptions[0]);
 
     for (int i = 0; i < count; ++i) {
@@ -227,6 +231,13 @@ void ScientificKeyPad::initButtons()
             }
         }
 
+        if (desc->button == Key_Point) {
+            QString decSym = Settings::instance()->getSystemDecimalSymbol();
+            if (decSym.isEmpty())
+                decSym = QStringLiteral(".");
+            button->setText(decSym);
+        }
+
         //stackwidget中按钮初始化
         if ((i / 6 > 0) && (i % 6 == 0 || i % 6 == 1) && i != 30 && i != 36) {
             DPushButton *pagebutton;
@@ -380,6 +391,7 @@ void ScientificKeyPad::initStackWidget(QStackedWidget *widget, DPushButton *butt
  */
 void ScientificKeyPad::buttonThemeChanged(int type)
 {
+    qDebug() << "Button theme changed to:" << (type == 2 ? "dark" : "light");
     m_themetype = type;
     QString path;
     if (type == 2) {
@@ -425,6 +437,7 @@ void ScientificKeyPad::buttonThemeChanged(int type)
  */
 void ScientificKeyPad::turnPage(int key)
 {
+    qDebug() << "Page turned with key:" << key;
     if (key == Key_page) {
         if (m_arcsinwidget->currentIndex() == 0) {
             m_arcsinwidget->setCurrentIndex(1);
@@ -459,6 +472,7 @@ void ScientificKeyPad::turnPage(int key)
  */
 void ScientificKeyPad::getdeg(int deg)
 {
+    qDebug() << "Angle unit changed to:" << (deg == 1 ? "rad" : deg == 2 ? "grad" : "deg");
     m_deg = deg;
     QString path;
     if (m_themetype == 2)
