@@ -126,7 +126,7 @@ int main(int argc, char *argv[])
     DSettingsAlt *m_dsettings = DSettingsAlt::instance();
     QDBusConnection dbus = QDBusConnection::sessionBus();
     qInfo() << "Registering DBus service";
-    if (dbus.registerService("com.deepin.calculator")) {
+    if (dbus.registerService("com.deepin.Calculator")) {
         qInfo() << "DBus service registered successfully";
         Dtk::Widget::moveToCenter(&window);
         m_dsettings->setOption("windowX", window.pos().x());
@@ -158,9 +158,9 @@ int main(int argc, char *argv[])
         DGuiApplicationHelper::instance()->setPaletteType(oldpalette);
     }
 
-    // Register debus service.
+    // Register D-Bus service.
     qDebug() << "Registering DBus object";
-    dbus.registerObject("/com/deepin/calculator", &window, QDBusConnection::ExportScriptableSlots);
+    dbus.registerObject("/com/deepin/calculator", &window);
     qInfo() << "Showing main window";
     window.show();
     window.switchModeBack();
