@@ -596,7 +596,21 @@ void MemoryWidget::setMemoryPublic(MemoryPublic *pub)
  */
 QString MemoryWidget::formatExpression(const QString &text)
 {
-    return QString(text)
+    QString t = text;
+
+    const auto sys = Settings::instance();
+    const QString decSym = sys->getSystemDecimalSymbol();
+    const QString grpSym = sys->getSystemDigitGroupingSymbol();
+    const QString decimalPlaceholder = QString(QChar(0x1D));
+
+    if (!decSym.isEmpty() && decSym != QLatin1String("."))
+        t.replace(decSym, decimalPlaceholder);
+    if (!grpSym.isEmpty() && grpSym != decSym)
+        t.replace(grpSym, "");
+    if (!decSym.isEmpty() && decSym != QLatin1String("."))
+        t.replace(decimalPlaceholder, QLatin1String("."));
+
+    return QString(t)
            .replace(CN_ADD, EN_ADD)
            .replace(CN_MIN, EN_MIN)
            .replace(CN_MUL, EN_MUL)
